/***************************************************************************
 *   Copyright (C) 2012-2024 by Ilya Kotov                                 *
 *   forkotov02@ya.ru                                                      *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
 ***************************************************************************/

#include <QMouseEvent>
#include "qsuitabbar.h"

QSUiTabBar::QSUiTabBar(QWidget *parent) : QTabBar(parent)
{}

void QSUiTabBar::mouseReleaseEvent(QMouseEvent *e)
{
    if(e->button() == Qt::MiddleButton)
    {
        int i = tabAt(e->pos());
        if(i >= 0)
        {
            e->accept();
            emit tabCloseRequested(i);
        }
    }
    QTabBar::mouseReleaseEvent(e);
}
